==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/OperatorHubStatusFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OperatorHubStatusFluent<A extends io.fabric8.openshift.api.model.OperatorHubStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToSources(java.lang.Integer index,io.fabric8.openshift.api.model.HubSourceStatus item);
  public A setToSources(java.lang.Integer index,io.fabric8.openshift.api.model.HubSourceStatus item);
  public A addToSources(io.fabric8.openshift.api.model.HubSourceStatus... items);
  public A addAllToSources(java.util.Collection<io.fabric8.openshift.api.model.HubSourceStatus> items);
  public A removeFromSources(io.fabric8.openshift.api.model.HubSourceStatus... items);
  public A removeAllFromSources(java.util.Collection<io.fabric8.openshift.api.model.HubSourceStatus> items);
  public A removeMatchingFromSources(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSources instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.HubSourceStatus> getSources();
  public java.util.List<io.fabric8.openshift.api.model.HubSourceStatus> buildSources();
  public io.fabric8.openshift.api.model.HubSourceStatus buildSource(java.lang.Integer index);
  public io.fabric8.openshift.api.model.HubSourceStatus buildFirstSource();
  public io.fabric8.openshift.api.model.HubSourceStatus buildLastSource();
  public io.fabric8.openshift.api.model.HubSourceStatus buildMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceStatusBuilder> predicate);
  public java.lang.Boolean hasMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceStatusBuilder> predicate);
  public A withSources(java.util.List<io.fabric8.openshift.api.model.HubSourceStatus> sources);
  public A withSources(io.fabric8.openshift.api.model.HubSourceStatus... sources);
  public java.lang.Boolean hasSources();
  public A addNewSource(java.lang.Boolean disabled,java.lang.String message,java.lang.String name,java.lang.String status);
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> addNewSource();
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> addNewSourceLike(io.fabric8.openshift.api.model.HubSourceStatus item);
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> setNewSourceLike(java.lang.Integer index,io.fabric8.openshift.api.model.HubSourceStatus item);
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> editSource(java.lang.Integer index);
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> editFirstSource();
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> editLastSource();
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> editMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceStatusBuilder> predicate);
  public interface SourcesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.HubSourceStatusFluent<io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<N>>{
    public N and();
    public N endSource();
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/OperatorHubStatusFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OperatorHubStatusFluent<A extends io.fabric8.openshift.api.model.OperatorHubStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToSources(java.lang.Integer index,io.fabric8.openshift.api.model.HubSourceStatus item);
  public A setToSources(java.lang.Integer index,io.fabric8.openshift.api.model.HubSourceStatus item);
  public A addToSources(io.fabric8.openshift.api.model.HubSourceStatus... items);
  public A addAllToSources(java.util.Collection<io.fabric8.openshift.api.model.HubSourceStatus> items);
  public A removeFromSources(io.fabric8.openshift.api.model.HubSourceStatus... items);
  public A removeAllFromSources(java.util.Collection<io.fabric8.openshift.api.model.HubSourceStatus> items);
  public A removeMatchingFromSources(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSources instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.HubSourceStatus> getSources();
  public java.util.List<io.fabric8.openshift.api.model.HubSourceStatus> buildSources();
  public io.fabric8.openshift.api.model.HubSourceStatus buildSource(java.lang.Integer index);
  public io.fabric8.openshift.api.model.HubSourceStatus buildFirstSource();
  public io.fabric8.openshift.api.model.HubSourceStatus buildLastSource();
  public io.fabric8.openshift.api.model.HubSourceStatus buildMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceStatusBuilder> predicate);
  public java.lang.Boolean hasMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceStatusBuilder> predicate);
  public A withSources(java.util.List<io.fabric8.openshift.api.model.HubSourceStatus> sources);
  public A withSources(io.fabric8.openshift.api.model.HubSourceStatus... sources);
  public java.lang.Boolean hasSources();
  public A addNewSource(java.lang.Boolean disabled,java.lang.String message,java.lang.String name,java.lang.String status);
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> addNewSource();
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> addNewSourceLike(io.fabric8.openshift.api.model.HubSourceStatus item);
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> setNewSourceLike(java.lang.Integer index,io.fabric8.openshift.api.model.HubSourceStatus item);
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> editSource(java.lang.Integer index);
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> editFirstSource();
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> editLastSource();
  public io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<A> editMatchingSource(java.util.function.Predicate<io.fabric8.openshift.api.model.HubSourceStatusBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface SourcesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.HubSourceStatusFluent<io.fabric8.openshift.api.model.OperatorHubStatusFluent.SourcesNested<N>>{
    public N and();
    public N endSource();
    
  }
  
}
